@@ -48,24 +48,24 @@ head(read.table(outfn, sep = "\t", header = TRUE))
 demo_file <- system.file("extdata", "demo/proteinpaint/fusions2pp_fusioncatcher.txt", package = "ngstk")
 input_data <- read.table(demo_file, sep = "\t", header = TRUE, stringsAsFactors = FALSE)
 # Get data subset according the defined rule
-mhander_extra_params = list(gene_5 = 1, gene_3 = 2, any_gene = "TCF3", fusions_any_match_flag = TRUE)
-result_1 <- fusions_filter(input_data, mhander_extra_params = mhander_extra_params)
+mhandler_extra_params = list(gene_5 = 1, gene_3 = 2, any_gene = "TCF3", fusions_any_match_flag = TRUE)
+result_1 <- fusions_filter(input_data, mhandler_extra_params = mhandler_extra_params)
 head(result_1)
 
-mhander_extra_params = list(gene_3 = 2, right_gene = "GYPA", fusions_right_match_flag = TRUE)
-result_2 <- fusions_filter(input_data, mhander_extra_params = mhander_extra_params)
+mhandler_extra_params = list(gene_3 = 2, right_gene = "GYPA", fusions_right_match_flag = TRUE)
+result_2 <- fusions_filter(input_data, mhandler_extra_params = mhandler_extra_params)
 head(result_2)
 
-mhander_extra_params = list(gene_5 = 1, left_gene = "GYPA", fusions_left_match_flag = TRUE)
-result_3 <- fusions_filter(input_data, mhander_extra_params = mhander_extra_params)
+mhandler_extra_params = list(gene_5 = 1, left_gene = "GYPA", fusions_left_match_flag = TRUE)
+result_3 <- fusions_filter(input_data, mhandler_extra_params = mhandler_extra_params)
 head(result_3)
 
-mhander_extra_params = list(gene_5 = 1, gene_3 = 2, left_gene = "GYPE", right_gene = "GYPA", fusions_full_match_flag = TRUE)
-result_4 <- fusions_filter(input_data, mhander_extra_params = mhander_extra_params)
+mhandler_extra_params = list(gene_5 = 1, gene_3 = 2, left_gene = "GYPE", right_gene = "GYPA", fusions_full_match_flag = TRUE)
+result_4 <- fusions_filter(input_data, mhandler_extra_params = mhandler_extra_params)
 head(result_4)
 
-mhander_extra_params = list(gene_5 = 1, gene_3 = 2, left_gene = "GYPE", right_gene = "GYPA", fusions_anyfull_match_flag = TRUE)
-result_5 <- fusions_filter(input_data, mhander_extra_params = mhander_extra_params)
+mhandler_extra_params = list(gene_5 = 1, gene_3 = 2, left_gene = "GYPE", right_gene = "GYPA", fusions_anyfull_match_flag = TRUE)
+result_5 <- fusions_filter(input_data, mhandler_extra_params = mhandler_extra_params)
 head(result_5)
 
 ## ------------------------------------------------------------------------
