@@ -1,8 +1,8 @@
 test_that("merge_table_files", {
   a <- data.frame(col1=1:6, col2=2:7)
   b <- data.frame(col1=6:11, col2=1:6)
-  file_a <- paste0(tempfile(), ".a")
-  file_b <- paste0(tempfile(), ".a")
+  file_a <- paste0(tempfile(), ".a_temp")
+  file_b <- paste0(tempfile(), ".a_temp")
   write.table(a, file_a, sep = "\t", row.names = FALSE)
   write.table(b, file_b, sep = "\t", row.names = FALSE)
   input_files <- c(file_a, file_b)
@@ -16,8 +16,8 @@ test_that("merge_table_files", {
   expect_that(colnames(x)[1], equals("col1"))
   expect_that(colnames(x)[2], equals("col2"))
   
-  outfn = tempfile()
-  x <- merge_table_files(files_dir = tempdir(), pattern = ".*.a$", outfn = outfn)
+  outfn = paste0(tempfile())
+  x <- merge_table_files(files_dir = tempdir(), pattern = ".*.a_temp$", outfn = outfn)
   expect_that(is.null(x), equals(TRUE))
   x <- read.table(outfn, header = TRUE, sep = "\t")
   expect_that(ncol(x), equals(3))
